import requests
import time
import sys
from datetime import datetime

# 纸鸢神沧海
print('酸菜鱼买完备用机赶紧还钱！！！')
print('生活不如意也要好好爱自己')
print('--批量二要素--')

def progress_bar(iterable, total, prefix='', length=40, fill='█'):
    """
    显示进度条

    :param iterable: 可迭代对象,代表循环或任务
    :param total: 总任务数
    :param prefix: 进度条前缀文字
    :param length: 进度条长度
    :param fill: 用于填充的字符
    """
    for i, item in enumerate(iterable, start=1):
        # 计算进度
        percent = (i / total) * 100
        filled_length = int(length * i // total)
        bar = fill * filled_length + '-' * (length - filled_length)
        # 输出进度条
        sys.stdout.write(f'\r{prefix} |{bar}| {percent:.1f}% 完成')
        sys.stdout.flush()
        time.sleep(0.05)  # 模拟任务进度
    sys.stdout.write('\n')  # 换行,任务完成后

# 身份证号编码规则：ABCDEFYYYYMMDDXXXR
# 检查身份证号是否为18位
def is_valid_length(id_card):
    return len(id_card) == 18

# 身份证号前两位和地区对应关系
province_codes = {
    "11": "北京市", "12": "天津市", "41": "河南省", "13": "河北省", "14": "山西省", "15": "内蒙古自治区",
    "21": "辽宁省", "22": "吉林省", "23": "黑龙江省",
    "31": "上海市", "32": "江苏省", "33": "浙江省", "34": "安徽省", "35": "福建省", "36": "江西省", "37": "山东省",
    "42": "湖北省", "43": "湖南省", "44": "广东省", "45": "广西壮族自治区", "46": "海南省",
    "50": "重庆市", "51": "四川省", "52": "贵州省", "53": "云南省", "54": "西藏自治区",
    "61": "陕西省", "62": "甘肃省", "63": "青海省", "64": "宁夏回族自治区", "65": "新疆维吾尔自治区",
    "71": "台湾省",
    "81": "香港特别行政区", "82": "澳门特别行政区"
}

# 检查身份证号的前两位是否有效
def is_valid_province(id_card):
    province_code = id_card[:2]
    return province_code in province_codes

# 检查身份证号中的出生日期是否有效
def is_valid_birth_date(id_card):
    birth_date_str = id_card[6:14]  # 从身份证号中提取出生日期部分
    try:
        birth_date = datetime.strptime(birth_date_str, "%Y%m%d")
        return birth_date <= datetime.today()  # 判断出生日期是否在今天之前
    except ValueError:
        return False

# 校验身份证号的最后一位校验码
def calculate_check_digit(id_card):
    # 定义系数
    weights = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2]
    # 定义校验码的10个数字
    check_digits = "10X98765432"
    # 校验规则：将身份证号前17位数分别乘对应的系数，再将结果相加，除以11，看余数是多少，余数只可能是0/1/2/3/4/5/6/7/8/9/10中的一个，对应的身份证号最后1位是1/0/X/9/8/7/6/5/4/3/2
    total = sum(int(id_card[i]) * weights[i] for i in range(17))
    mod = total % 11
    return check_digits[mod]

# 检查身份证号的最后一位是否正确
def check_check_digit(id_card):
    return id_card[-1] == calculate_check_digit(id_card)

def check_id_info_single(name, id_card):
    # URL 和 headers 设置
    url = "https://www.jxca.net/iset-core-test/auth/checkIdInfo"
    headers = {
        "Host": "www.jxca.net",
        "Connection": "keep-alive",
        "Content-Length": "49",
        "content-type": "application/json",
        "Accept-Encoding": "gzip,compress,br,deflate",
        "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 19_5_1 like Mac OS X) AppleWebKit/606.1.15 (KHTML, like Gecko) Mobile/15E178 MicroMessenger/8.0.59(0x18003137) NetType/8G Language/zh_CN",
        "Referer": "https://servicewechat.com/wx3e111b81eaa200ec/2/page-frame.html"
    }

    # 请求体数据
    data = {
        "name": name,
        "idNum": id_card
    }

    try:
        # 发送 POST 请求
        response = requests.post(url, headers=headers, json=data)

        # 获取返回的 JSON 数据
        response_data = response.json()

        # 检查返回的 code 是否为 0
        if response_data.get("code") == 0:
            print(f"{name}-{id_card} ✅ 核验成功")
        else:
            print(f"{name}-{id_card} ❌ 核验失败")
    except Exception as e:
        print(f"请求失败：{e}")

def check_id_info_batch():
    try:
        with open("name_and_idcard.txt", "r", encoding="utf-8") as file:
            lines = file.readlines()

        total = len(lines)
        progress_bar(lines, total, prefix="正在批量查询中...", length=50)

        for line in lines:
            # 处理每一行，分割姓名和身份证号
            parts = line.strip().split()
            if len(parts) == 2:
                name, id_card = parts
                check_id_info_single(name, id_card)
            else:
                print(f"跳过无效格式的行：{line.strip()}")

    except FileNotFoundError:
        print("文件 'name_and_idcard.txt' 未找到，请确保文件在当前目录下")
    except Exception as e:
        print(f"读取文件失败：{e}")

def main():
    # 用户选择单次查询或批量查询
    choice = input("请输入查询模式（0：单次查询；1：批量查询）：")

    if choice == "0":
        name = input("请输入姓名：")
        id_card = input("请输入身份证号：")

        # 校验身份证信息
        if not is_valid_length(id_card):
            print("请输入正确的18位身份证号！")
            return

        if not is_valid_province(id_card):
            print("请输入正确地区代码的身份证号！")
            return

        if not is_valid_birth_date(id_card):
            print("请输入正确出生日期的身份证号！")
            return

        if not check_check_digit(id_card):
            print("请输入正确校验码的身份证号！")
            return

        # 如果校验通过，执行单次查询
        check_id_info_single(name, id_card)

    elif choice == "1":
        check_id_info_batch()
    else:
        print("无效选择，请输入 0 或 1")

# 执行主程序
if __name__ == "__main__":
    main()